@@ -60,6 +60,14 @@ class ManagedPolicyOnUserRule(Rule):
           }
         }
         ```
+
+    Filters context:
+        | Parameter               | Type                             | Description                                                    |
+        |:-----------------------:|:--------------------------------:|:--------------------------------------------------------------:|
+        |`config`                 | str                              | `config` variable available inside the rule                    |
+        |`extras`                 | str                              | `extras` variable available inside the rule                    |
+        |`logical_id`             | str                              | ID used in Cloudformation to refer the resource being analysed |
+        |`resource`               | `IAMManagedPolicy`               | Resource that is being addressed                               |
     """
 
     REASON = "IAM managed policy {} should not apply directly to users. Should be on group"
@@ -69,5 +77,10 @@ class ManagedPolicyOnUserRule(Rule):
         result = Result()
         for logical_id, resource in cfmodel.Resources.items():
             if isinstance(resource, IAMManagedPolicy) and resource.Properties.Users:
-                self.add_failure_to_result(result, self.REASON.format(logical_id), resource_ids={logical_id})
+                self.add_failure_to_result(
+                    result,
+                    self.REASON.format(logical_id),
+                    resource_ids={logical_id},
+                    context={"config": self._config, "extras": extras, "logical_id": logical_id, "resource": resource},
+                )
         return result
